#! /bin/sh

# Get source path.
if [ -z "$SRCPATH" ]; then
	SRCPATH="/usr/src/linux"
	echo "Assuming kernel sources are located at $SRCPATH..."
fi
if [ ! -d "$SRCPATH/include" ]; then
	echo "Source path \"$SRCPATH\" doesn't exist (or it doesn't contain"
	echo "subdirectory \"include\"). This path should point to your"
	echo "kernel sources."
	echo ""
	echo "You can provide path in SRCPATH."
	exit 1
fi

# Get compiler.
if [ -z "$CC" ]; then
	CC=gcc
	echo "Using $CC as compiler."
fi
CC=$(which $CC)

if [ ! -x $CC ]; then
	echo "Cannot run \"$CC\"."
	echo "You can provide compiler in CC."
	exit 1
fi

echo ""
echo "Compiling..."
echo "(Don't worry about possible \"obsolete\"-warnings, they are harmless.)"
echo ""

# Get kernel version.
KERNEL_VERSION_FULL=$(uname -sr)
KERNEL_VERSION_NUMBER=$(uname -r)
# ...and module path.
MODULE_PATH="/lib/modules/$KERNEL_VERSION_NUMBER/kernel/drivers/char/joystick"

$CC -D__KERNEL__ -I"$SRCPATH"/include -Wall -Wstrict-prototypes \
		-Wno-trigraphs -O2 -fomit-frame-pointer -fno-strict-aliasing \
		-fno-common -pipe -mpreferred-stack-boundary=2 \
		-malign-functions=4 -DMODULE -DMODVERSIONS \
		-include "$SRCPATH"/include/linux/modversions.h \
		-c -o gamecon.o gamecon.c

if [ $? -eq 0 ]; then
	echo ""
	echo "All done, you should have gamecon.o in your working directory."
	echo "This module *should* be able to replace your stock-gamecon, "
	echo "but if I was you, I would try loading it with insmod before"
	echo "replacing the original one (even then I would make a backup of"
	echo "the old one)."
	echo ""
	echo "If you think everything went fine, go ahead and type "
	echo "cp gamecon.o $MODULE_PATH"
	echo "and answer \"yes\" if requested to confirm file overwrite."
	echo ""
	echo "Whatever you do, remember it's the kernel you're playing with. :-)"
	echo ""
	exit 0
else
	exit 1
fi
